========================
Asset valuation overview
========================

Functions to support assets valuation for finance, accounting, and modelling.

Acknowledgments
===============

The module was kick-started with the support of `Lipartner AG <https://www.lipartner.ch>`_.

Installation
============

The module can be installed using ``pip`` either by downloading a `release <https://gitlab.wemod.ch/kakila/assetvaluation/-/releases>`_ or a `snapshot of the repository <https://gitlab.wemod.ch/kakila/assetvaluation/-/archive/master/assetvaluation-master.zip>`_, or by cloning the repository.

To install run ``pip install <path-to-module>``, where `<path-to-module>` indicates the path to the module:

`development <https://gitlab.wemod.ch/kakila/assetvaluation/tree/master>`_ :
  `pip install https://gitlab.wemod.ch/kakila/assetvaluation/`

`PyPI version <https://pypi.org/project/assetvaluation/>`_ :
  `pip install assetvaluation`

If you have cloned(downloaded) the repository ``<path-to-module>`` is the full path to the folder
where you have the clone(archived file).

Documentation
=============

The html documentation is hosted at https://kakila.wemod.info/assetvaluation

Compiling the documentation
***************************

The sources can be found in the folder |docfolder|_ of the repository.

.. |docfolder| replace:: ``doc``
.. _docfolder : https://gitlab.wemod.ch/kakila/assetvaluation/tree/master/doc>

To compile the documentation you will need `sphinx <https://www.sphinx-doc.org>`_ in addition
to the runtime dependencies of the module.
See the |requirementsfile|_ file for details.

.. |requirementsfile| replace:: ``requirements.txt``
.. _requirementsfile:  https://gitlab.wemod.ch/kakila/assetvaluation/raw/master/requirements.txt

Once you have sphinx, you can compile the documentation by running the command ``make html``
in the ``doc`` folder.
